@@ -3,6 +3,8 @@
 
 from derpconf.config import Config  # NOQA
 
+MINUTE = 60
+HOUR = MINUTE * 60
 
 Config.define('WORKER_SLEEP_TIME', 10, 'Main loop sleep time', 'Worker')
 Config.define('ZOMBIE_WORKER_TIME', 200,
@@ -22,6 +24,7 @@ Config.define('LOG_DATE_FORMAT', '%Y-%m-%d %H:%M:%S',
 Config.define('FACTERS', [], 'List of classes to get facts about a website', 'Review')
 Config.define('VALIDATORS', [], 'List of classes to validate a website', 'Review')
 Config.define('REVIEW_EXPIRATION_IN_SECONDS', 6 * 60 * 60, 'Number of seconds that a review expires in.', 'Review')
+Config.define('NUMBER_OF_REVIEWS_TO_KEEP', 4, 'Maximum number of reviews to keep', 'Review')
 
 Config.define('MAX_ENQUEUE_BUFFER_LENGTH', 1000,
               'Number of urls to enqueue before submitting to the /pages route', 'Validators')
@@ -82,7 +85,6 @@ Config.define('ERROR_HANDLERS', [], 'List of classes to handle errors', 'General
 Config.define('USE_SENTRY', False, 'If set to true errors will be sent to sentry.', 'Sentry')
 Config.define('SENTRY_DSN_URL', '', 'URL to use as sentry DSN.', 'Sentry')
 
-HOUR = 60 * 60
 Config.define('PAGE_COUNT_EXPIRATION_IN_SECONDS', HOUR, 'Expiration for the cache key for each domain page count', 'Cache')
 Config.define('VIOLATION_COUNT_EXPIRATION_IN_SECONDS', HOUR, 'Expiration for the cache key for each domain violation count', 'Cache')
 Config.define('ACTIVE_REVIEW_COUNT_EXPIRATION_IN_SECONDS', HOUR, 'Expiration for the cache key for each domain violation count', 'Cache')
@@ -97,6 +99,21 @@ Config.define('NEXT_JOB_URL_LOCK_EXPIRATION_IN_SECONDS', 3 * 60, 'Expiration for
 Config.define('NEXT_JOBS_COUNT_EXPIRATION_IN_SECONDS', HOUR, 'Expiration for the cache key for next jobs count', 'Cache')
 Config.define('REQUESTS_COUNT_EXPIRATION_IN_SECONDS', HOUR, 'Expiration for the cache key for requests count', 'Cache')
 
+materials_expiration_in_seconds = {
+    'domains_details': 0.5 * MINUTE + 1,
+    'next_jobs_count': 13,
+    'violation_count_by_category_for_domains': 3 * MINUTE + 7,
+    'blacklist_domain_count': 10 * MINUTE + 1
+}
+Config.define('MATERIALS_EXPIRATION_IN_SECONDS', materials_expiration_in_seconds, 'Expire times for materials', 'material')
+
+materials_grace_period_in_seconds = {
+    'domains_details': 2 * materials_expiration_in_seconds['domains_details'],
+    'next_jobs_count': 2 * materials_expiration_in_seconds['next_jobs_count'],
+    'violation_count_by_category_for_domains': 2 * materials_expiration_in_seconds['violation_count_by_category_for_domains'],
+    'blacklist_domain_count': 2 * materials_expiration_in_seconds['blacklist_domain_count'],
+}
+Config.define('MATERIALS_GRACE_PERIOD_IN_SECONDS', materials_grace_period_in_seconds, 'Grace period times for materials', 'material')
 
 Config.define('DEFAULT_PAGE_SCORE', 1000000, 'Page Score for pages that the user includes through the UI', 'General')
 Config.define('PAGE_SCORE_TAX_RATE', 0.1, 'Default tax rate for scoring pages.', 'General')
@@ -114,4 +131,8 @@ Config.define('DEFAULT_NUMBER_OF_CONCURRENT_CONNECTIONS', 5, 'Default number of
 Config.define('MOST_COMMON_VIOLATIONS_CACHE_EXPIRATION', 3 * HOUR, 'Expiration for the cache key for the most common violations', 'Cache')
 Config.define('MOST_COMMON_VIOLATIONS_SAMPLE_LIMIT', 50000, 'Limit for the size of the Vilation sample used in the aggregation', 'Violation Handler')
 
-Config.define('EVENT_BUS_THROTTLING_MESSAGE_TYPE', {}, 'Trottling by message type', 'Event Bus')
+throttling_message_type = {
+    'new-request': 5,
+    'worker-status': 2,
+}
+Config.define('EVENT_BUS_THROTTLING_MESSAGE_TYPE', throttling_message_type, 'Trottling by message type', 'Event Bus')
