@@ -38,7 +38,7 @@ class BaseHandler(RequestHandler):
     def options(self):
         self.set_header('Access-Control-Allow-Origin', self.application.config.ORIGIN)
         self.set_header('Access-Control-Allow-Methods', 'GET,PUT,POST,DELETE,OPTIONS')
-        self.set_header('Access-Control-Allow-Headers', 'Accept, Content-Type')
+        self.set_header('Access-Control-Allow-Headers', 'Accept, Content-Type, X-AUTH-HOLMES')
         self.set_status(200)
         self.finish()
 
@@ -61,3 +61,8 @@ class BaseHandler(RequestHandler):
             #self._session = self.application.get_sqlalchemy_session()
 
         #return self._session
+
+    @property
+    def girl(self):
+        return self.application.girl
+
