@@ -86,127 +86,6 @@ class DomainDetailsHandler(BaseHandler):
         self.write_json(domain_json)
 
 
-class DomainPageCountHandler(BaseHandler):
-
-    @coroutine
-    def get(self, domain_name):
-        domain = Domain.get_domain_by_name(domain_name, self.db)
-
-        if not domain:
-            self.set_status(404, 'Domain %s not found' % domain_name)
-            return
-
-        page_count = yield self.cache.get_page_count(domain)
-
-        domain_json = {
-            "id": domain.id,
-            "name": domain.name,
-            "url": domain.url,
-            "is_active": domain.is_active,
-            "pageCount": page_count
-        }
-
-        self.write_json(domain_json)
-
-
-class DomainReviewCountHandler(BaseHandler):
-
-    @coroutine
-    def get(self, domain_name):
-        domain = Domain.get_domain_by_name(domain_name, self.db)
-
-        if not domain:
-            self.set_status(404, 'Domain %s not found' % domain_name)
-            return
-
-        review_count = yield self.cache.get_active_review_count(domain)
-
-        domain_json = {
-            "id": domain.id,
-            "name": domain.name,
-            "url": domain.url,
-            "is_active": domain.is_active,
-            "reviewCount": review_count
-        }
-
-        self.write_json(domain_json)
-
-
-class DomainViolationCountHandler(BaseHandler):
-
-    @coroutine
-    def get(self, domain_name):
-        domain = Domain.get_domain_by_name(domain_name, self.db)
-
-        if not domain:
-            self.set_status(404, 'Domain %s not found' % domain_name)
-            return
-
-        violation_count = yield self.cache.get_violation_count(domain)
-
-        domain_json = {
-            "id": domain.id,
-            "name": domain.name,
-            "url": domain.url,
-            "is_active": domain.is_active,
-            "violationCount": violation_count
-        }
-
-        self.write_json(domain_json)
-
-
-class DomainErrorPercentageHandler(BaseHandler):
-
-    @coroutine
-    def get(self, domain_name):
-        domain = Domain.get_domain_by_name(domain_name, self.db)
-
-        if not domain:
-            self.set_status(404, 'Domain %s not found' % domain_name)
-            return
-
-        bad_request_count = yield self.cache.get_bad_request_count(domain)
-        good_request_count = yield self.cache.get_good_request_count(domain)
-        total_request_count = good_request_count + bad_request_count
-        if total_request_count > 0:
-            error_percentage = round(float(bad_request_count) / total_request_count * 100, 2)
-        else:
-            error_percentage = 0
-
-        domain_json = {
-            "id": domain.id,
-            "name": domain.name,
-            "url": domain.url,
-            "is_active": domain.is_active,
-            "errorPercentage": error_percentage
-        }
-
-        self.write_json(domain_json)
-
-
-class DomainResponseTimeAvgHandler(BaseHandler):
-
-    @coroutine
-    def get(self, domain_name):
-        domain = Domain.get_domain_by_name(domain_name, self.db)
-
-        if not domain:
-            self.set_status(404, 'Domain %s not found' % domain_name)
-            return
-
-        response_time_avg = yield self.cache.get_response_time_avg(domain)
-
-        domain_json = {
-            "id": domain.id,
-            "name": domain.name,
-            "url": domain.url,
-            "is_active": domain.is_active,
-            "averageResponseTime": response_time_avg,
-        }
-
-        self.write_json(domain_json)
-
-
 class DomainViolationsPerDayHandler(BaseHandler):
 
     def get(self, domain_name):
@@ -249,18 +128,13 @@ class DomainReviewsHandler(BaseHandler):
             page_size=page_size
         )
 
-        page_count = yield self.cache.get_page_count(domain)
         if term:
-            review_count = domain.get_active_review_count(url_starts_with=term, db=self.db)
+            review_count = len(reviews)
         else:
             review_count = yield self.cache.get_active_review_count(domain)
 
         result = {
-            "domainId": domain.id,
-            'domainName': domain.name,
-            'domainURL': domain.url,
             'reviewCount': review_count,
-            'pageCount': page_count,
             'pages': [],
         }
 
@@ -293,7 +167,7 @@ class DomainGroupedViolationsHandler(BaseHandler):
         total = 0
         violations = []
 
-        for item in grouped_violations.get(domain.id, None):
+        for item in grouped_violations.get(domain.id, []):
             key_name, key_category_id, count = item['key_name'], item['category_id'], item['violation_count']
             violations.append({
                 'categoryId': key_category_id,
